QA4MRE dataset was created for the CLEF 2011/2012/2013 shared tasks to promote
research in question answering and reading comprehension. The dataset contains a
supporting passage and a set of questions corresponding to the passage. Multiple
options for answers are provided for each question, of which only one is
correct. The training and test datasets are available for the main track.
Additional gold standard documents are available for two pilot studies: one on
alzheimers data, and the other on entrance exams data.
